﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Data;

using Syncfusion.XlsIO;

namespace SyncfusionTest
{
    class generateExcel
    {
        ExcelEngine m_excelEngine = new ExcelEngine();
        IApplication m_application = null;
        IWorkbook m_workbook = null;
        string m_path = "C:\\pegtmp\\syncfusiontest\\SyncfusionTest\\Data";

        /// <summary>
        ///    Constructor
        /// </summary>
        /// <param name="filename"></param>
        public generateExcel()
        {
            //Instantiate the excel application object.
            this.m_application = this.m_excelEngine.Excel;

            // Opening the Existing Worksheet from a Workbook
            this.m_workbook = this.m_excelEngine.Excel.Workbooks.Open(this.m_path + "\\Excel_Unternehmensprojekte.xls");

            DataSet testData = new DataSet();
            testData.ReadXml(this.m_path + "\\testdata.xml");
            this.FillExcel(testData.Tables["Data"]);
        }

        /// <summary>
        ///  Hier werden die Daten abgefüllt
        /// </summary>
        /// <param name="httpResponse"></param>
        private void FillExcel(DataTable data)
        {
            IWorksheet sheet = this.m_workbook.Worksheets["laufend"];

            this.FillExcelDetailed(sheet, data);

            ////Saving the workbook to disk.
            this.m_workbook.SaveAs(this.m_path+"\\Unternehmensprojekte.xls", ExcelSaveType.SaveAsXLS);

            //No exception will be thrown if there are unsaved workbooks.

            this.m_excelEngine.ThrowNotSavedOnDestroy = false;

            this.m_excelEngine.Dispose();

        }

        /// <summary>
        ///    Methode, die die Detailarbeit verrichtet
        /// </summary>
        /// <param name="sheet">Entsprechendes Sheet</param>
        /// <param name="data">Die DataTable</param>
        private void FillExcelDetailed(IWorksheet sheet, DataTable data)
        {
            //notwendige Zeilen hinzufügen
            for (int i = 0; i < data.Rows.Count; i++)
            {
                sheet.InsertRow(23);
            }

            sheet.Range["J15"].Text = "Stand ";
            sheet.Range["O15"].Text = "Stand ";
            sheet.Range["B8"].Text = "Portfolio";
            sheet.Range["B8"].CellStyle.Font.Bold = true;

            int rowStart = 22;
            int rowEnde = data.Rows.Count + 21;

            if (data.Rows.Count > 0)
            {
                sheet.Range["Y" + rowStart.ToString() + ":Y" + rowEnde.ToString()].WrapText = true;
                sheet.Range["AA" + rowStart.ToString() + ":AA" + rowEnde.ToString()].WrapText = true;

                // Optimale Spaltenhöhe einstellen
                sheet.Range["A" + rowStart.ToString() + ":AA" + rowEnde.ToString()].Activate();
                sheet.Range["A" + rowStart.ToString() + ":AA" + rowEnde.ToString()].EntireRow.AutofitRows();
            }
            for (int i = 0; i < data.Rows.Count; i++)
            {
                int row = i + 22;
                for (int j = 1; j < data.Columns.Count; j++)
                {
                    int column = j;

                    if (j > 7) column = column + 2;
                    if (j > 11) column = column + 1;
                    if (j > 22) column = column + 1;

                    sheet.Range[row, column].CellStyle.Font.FontName = "Arial";
                    sheet.Range[row, column].CellStyle.Font.Size = 12;

                    if (data.Columns[j].DataType.Name.Contains("DateTime"))
                    {
                        sheet.Range[row, column].CellStyle.HorizontalAlignment = ExcelHAlign.HAlignRight;
                        sheet.Range[row, column].Text = ((DateTime)data.Rows[i][j]).ToShortDateString();
                    }
                    else
                    {
                        //falls wir hier Ampelwerte haben, dann Grafiken einfügen
                        if (data.Columns[j].ColumnName.Contains("Ampeln."))
                        {
                            IPictureShape pic = sheet.Pictures.AddPicture(row, column, this.m_path + "\\Status" + data.Rows[i][j].ToString() + ".gif", 100, 100);
                            pic.Left += (int)Math.Round(sheet.Range[row, column].ColumnWidth * 3);
                        }
                        else
                        {
                            if (data.Columns[j].DataType.Name.Contains("Double"))
                                sheet.Range[row, column].Number = System.Convert.ToDouble(data.Rows[i][j].ToString());
                            else
                                sheet.Range[row, column].Text = data.Rows[i][j].ToString();
                        }
                    }
                }
                sheet.Range["M" + row.ToString()].Formula = "J" + row.ToString() + "+K" + row.ToString() + "-L" + row.ToString();
            }

            //Alle Pics wieder auf ihre ursprüngliche Höhe von 15 setzen:
            for (int j = 0; j < sheet.Pictures.Count; j++)
            {
                sheet.Pictures[j].Scale(100, 100);
            }
        }
    }
}
